.vitalstyles-reset {
  /**
     * html5doctor.com Reset Stylesheet v1.6.1 (http://html5doctor.com/html-5-reset-stylesheet/)
     * Richard Clark (http://richclarkdesign.com)
     * http://cssreset.com
     */
  line-height: 1;
  /* change colours to suit your needs */
  /* change colours to suit your needs */
  /* change border colour to suit your needs */
}
.vitalstyles-reset,
.vitalstyles-reset div,
.vitalstyles-reset span,
.vitalstyles-reset object,
.vitalstyles-reset iframe,
.vitalstyles-reset h1,
.vitalstyles-reset h2,
.vitalstyles-reset h3,
.vitalstyles-reset h4,
.vitalstyles-reset h5,
.vitalstyles-reset h6,
.vitalstyles-reset p,
.vitalstyles-reset blockquote,
.vitalstyles-reset pre,
.vitalstyles-reset abbr,
.vitalstyles-reset address,
.vitalstyles-reset cite,
.vitalstyles-reset code,
.vitalstyles-reset del,
.vitalstyles-reset dfn,
.vitalstyles-reset em,
.vitalstyles-reset img,
.vitalstyles-reset ins,
.vitalstyles-reset kbd,
.vitalstyles-reset q,
.vitalstyles-reset samp,
.vitalstyles-reset small,
.vitalstyles-reset strong,
.vitalstyles-reset sub,
.vitalstyles-reset sup,
.vitalstyles-reset var,
.vitalstyles-reset b,
.vitalstyles-reset i,
.vitalstyles-reset dl,
.vitalstyles-reset dt,
.vitalstyles-reset dd,
.vitalstyles-reset ol,
.vitalstyles-reset ul,
.vitalstyles-reset li,
.vitalstyles-reset fieldset,
.vitalstyles-reset form,
.vitalstyles-reset label,
.vitalstyles-reset legend,
.vitalstyles-reset table,
.vitalstyles-reset caption,
.vitalstyles-reset tbody,
.vitalstyles-reset tfoot,
.vitalstyles-reset thead,
.vitalstyles-reset tr,
.vitalstyles-reset th,
.vitalstyles-reset td,
.vitalstyles-reset article,
.vitalstyles-reset aside,
.vitalstyles-reset canvas,
.vitalstyles-reset details,
.vitalstyles-reset figcaption,
.vitalstyles-reset figure,
.vitalstyles-reset footer,
.vitalstyles-reset header,
.vitalstyles-reset hgroup,
.vitalstyles-reset menu,
.vitalstyles-reset nav,
.vitalstyles-reset section,
.vitalstyles-reset summary,
.vitalstyles-reset time,
.vitalstyles-reset mark,
.vitalstyles-reset audio,
.vitalstyles-reset video {
  margin: 0;
  padding: 0;
  border: 0;
  outline: 0;
  font-size: 100%;
  vertical-align: baseline;
  background: transparent;
}
.vitalstyles-reset article,
.vitalstyles-reset aside,
.vitalstyles-reset details,
.vitalstyles-reset figcaption,
.vitalstyles-reset figure,
.vitalstyles-reset footer,
.vitalstyles-reset header,
.vitalstyles-reset hgroup,
.vitalstyles-reset menu,
.vitalstyles-reset nav,
.vitalstyles-reset section {
  display: block;
}
.vitalstyles-reset nav ul {
  list-style: none;
}
.vitalstyles-reset blockquote,
.vitalstyles-reset q {
  quotes: none;
}
.vitalstyles-reset blockquote:before,
.vitalstyles-reset blockquote:after,
.vitalstyles-reset q:before,
.vitalstyles-reset q:after {
  content: '';
  content: none;
}
.vitalstyles-reset a {
  margin: 0;
  padding: 0;
  font-size: 100%;
  vertical-align: baseline;
  background: transparent;
}
.vitalstyles-reset ins {
  background-color: #ff9;
  color: #000;
  text-decoration: none;
}
.vitalstyles-reset mark {
  background-color: #ff9;
  color: #000;
  font-style: italic;
  font-weight: bold;
}
.vitalstyles-reset del {
  text-decoration: line-through;
}
.vitalstyles-reset abbr[title],
.vitalstyles-reset dfn[title] {
  border-bottom: 1px dotted;
  cursor: help;
}
.vitalstyles-reset table {
  border-collapse: collapse;
  border-spacing: 0;
}
.vitalstyles-reset hr {
  display: block;
  height: 1px;
  border: 0;
  border-top: 1px solid #cccccc;
  margin: 1em 0;
  padding: 0;
}
.vitalstyles-reset input,
.vitalstyles-reset select {
  vertical-align: middle;
}
.vitalstyles-reset {
  font-family: "HelveticaNeue-Light", "Helvetica Neue Light", "Helvetica Neue", HelveticaNeue, "Helvetica-Neue", Helvetica, Arial, sans-serif;
  font-size: 14px;
  padding-left: 30px;
  padding-right: 30px;
}
.vitalstyles-reset h1,
.vitalstyles-reset h2 {
  font-weight: normal;
}
.vitalstyles-reset h1 {
  font-size: 35px;
}
.vitalstyles-reset h2 {
  font-size: 27px;
}
.vitalstyles-reset ul,
.vitalstyles-reset ol {
  margin-left: 30px;
}
.vitalstyles-reset.vitalstyles-header {
  background-color: #fafafa;
  padding-top: 70px;
  padding-bottom: 70px;
}
.vitalstyles-reset.vitalstyles-header h1 {
  font-size: 50px;
  color: #333;
  margin: 0;
}
.vitalstyles-reset.vitalstyles-header p {
  font-size: 16px;
  font-weight: bold;
  color: #666;
}
.vitalstyles-reset.vitalstyles-toc {
  padding-top: 40px;
  padding-bottom: 40px;
}
.vitalstyles-reset.vitalstyles-toc h2 {
  margin: 0;
  padding: 0;
  font-size: 18px;
  color: #444;
}
.vitalstyles-reset.vitalstyles-toc ul li {
  margin-top: 10px;
}
.vitalstyles-reset.vitalstyles-toc ul li a {
  color: #666;
  text-decoration: none;
  border-bottom: 1px solid #eee;
  transition-property: border;
  transition-duration: 0.3s;
}
.vitalstyles-reset.vitalstyles-toc ul li a:hover {
  color: #333;
  text-decoration: none;
  border-bottom: 3px solid #ccc;
}
.vitalstyles-reset.vitalstyles-filename-block {
  padding: 0;
}
.vitalstyles-reset.vitalstyles-filename-block .vitalstyles-filename-block-spacing {
  height: 60px;
  background-color: #2a2a2a;
}
.vitalstyles-reset.vitalstyles-filename-block h1 {
  margin: 0;
  padding: 0 30px;
  color: #666666;
  font-size: 20px;
  background-color: #333;
  padding-top: 40px;
  padding-bottom: 40px;
}
.vitalstyles-reset.vitalstyles-markdown {
  background-color: #2a2a2a;
  color: #999;
}
.vitalstyles-reset.vitalstyles-markdown h1 {
  margin: 0;
  padding-top: 40px;
  padding-bottom: 16px;
}
.vitalstyles-reset.vitalstyles-markdown p {
  margin: 0;
  padding: 14px 0 14px 0;
}
.vitalstyles-reset.vitalstyles-markdown p + p {
  padding-top: 0;
}
.vitalstyles-reset.vitalstyles-markdown h2,
.vitalstyles-reset.vitalstyles-markdown h3,
.vitalstyles-reset.vitalstyles-markdown h4,
.vitalstyles-reset.vitalstyles-markdown h5,
.vitalstyles-reset.vitalstyles-markdown h6 {
  margin: 0;
  padding: 20px 0 12px 0;
}
.vitalstyles-reset.vitalstyles-markdown h2 + p,
.vitalstyles-reset.vitalstyles-markdown h3 + p,
.vitalstyles-reset.vitalstyles-markdown h4 + p,
.vitalstyles-reset.vitalstyles-markdown h5 + p,
.vitalstyles-reset.vitalstyles-markdown h6 + p {
  padding-top: 0;
}
.vitalstyles-reset.vitalstyles-markdown pre {
  margin: 0;
}
.vitalstyles-reset.vitalstyles-markdown code {
  border-width: 0;
  background-color: #444;
  color: #aaa;
  padding: 2px 4px;
  font-size: 90%;
  white-space: nowrap;
  border-radius: 4px;
  font-family: Menlo, Monaco, Consolas, "Courier New", monospace;
}
.vitalstyles-example {
  background-color: #2a2a2a;
}
.vitalstyles-example .vitalstyles-example-previewblock {
  background-color: #fff;
}
.vitalstyles-example .vitalstyles-example-codeblock {
  background-color: #2a2a2a;
  padding-left: 30px;
  padding-right: 30px;
  padding-bottom: 10px;
}
.vitalstyles-example .vitalstyles-example-codeblock pre {
  margin: 0;
  padding: 10px 15px;
}
.vitalstyles-example .vitalstyles-example-previewblock-heading,
.vitalstyles-example .vitalstyles-example-codeblock-heading {
  background-color: #2a2a2a;
}
.vitalstyles-example .vitalstyles-example-previewblock-heading h5,
.vitalstyles-example .vitalstyles-example-codeblock-heading h5 {
  font-size: 14px;
  color: #888;
  font-weight: bold;
  padding: 15px 0 4px 0;
  margin: 0;
  text-transform: uppercase;
}
.vitalstyles-example.vitalstyles-example-default .vitalstyles-example-previewblock {
  margin-left: 30px;
  margin-right: 30px;
  padding: 10px 15px;
}
.vitalstyles-example.vitalstyles-example-isolated .vitalstyles-example-previewblock iframe {
  width: 100%;
  border: none;
  margin: 0;
  height: 400px;
}
.vitalstyles-example.vitalstyles-example-isolated .vitalstyles-example-previewblock > .vitalstyles-example-isolated-openwrapper {
  background-color: #2a2a2a;
  padding-top: 15px;
  padding-bottom: 10px;
}
.vitalstyles-example.vitalstyles-example-isolated .vitalstyles-example-previewblock > .vitalstyles-example-isolated-openwrapper a {
  color: #eee;
  background-color: #444;
  border: 1px solid #000;
  border-radius: 3px;
  text-decoration: none;
  padding: 8px 12px;
}
.vitalstyles-example.vitalstyles-example-isolated .vitalstyles-example-previewblock > .vitalstyles-example-isolated-openwrapper a:hover {
  background-color: #000;
  text-decoration: none;
  color: #fff;
}
