<iframe class="vitalstyles-example-isolated-iframe" src="{{ previewfilename }}"></iframe>
<p class="vitalstyles-reset vitalstyles-example-isolated-openwrapper">
    <a href="{{ previewfilename }}">Open example</a>
</p>