{#
    We wrap each example in:

        </div>
            ...
        <div class="vitalstyles-reset vitalstyles-markdown">

    Additionally, the markdownparser wraps the entire markdown
    document in:

        <div class="vitalstyles-reset vitalstyles-markdown">
        </div>

    This means that we can style the markdown blocks with styles
    scoped to ``.vitalstyles-markdown``, without affecting the
    example previews.
#}
</div> {# End the previous <div class="vitalstyles-reset vitalstyles-markdown"> #}
    {% block content %}
        <div class="vitalstyles-example vitalstyles-example-{{ examplestyle }}">
            <div class="vitalstyles-reset vitalstyles-example-previewblock-heading">
                <h5>Example</h5>
            </div>
            <div class="vitalstyles-example-previewblock">{{ previewblock }}</div>

            <div class="vitalstyles-reset vitalstyles-example-codeblock-heading">
                <h5>Code for the example</h5>
            </div>
            <div class="vitalstyles-reset vitalstyles-example-codeblock">{{ codeblock }}</div>
        </div>
    {% endblock content %}
<div class="vitalstyles-reset vitalstyles-markdown">